==> haskell-pandoc-types-1.17.5.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.5.1
id: pandoc-types-1.17.5.1-5uvsrS3PKqX1adT6me18EE
key: pandoc-types-1.17.5.1-5uvsrS3PKqX1adT6me18EE
license: BSD-3-Clause
copyright: (c) 2006-2017 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
abi: 2c9ce81eeb2cdf7612a88a51e20306d5
exposed: True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk
hidden-modules: Paths_pandoc_types
import-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-types-1.17.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-types-1.17.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pandoc-types-1.17.5.1
hs-libraries: HSpandoc-types-1.17.5.1-5uvsrS3PKqX1adT6me18EE
depends:
    base-4.11.1.0 containers-0.5.11.0 syb-0.7-2jW43lwzJV5e7EQvU8PxV
    ghc-prim-0.5.2.0 bytestring-0.10.8.2
    aeson-1.3.1.1-5HUAx09wxP9QY0dgM2orK transformers-0.5.5.0
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=5f5748e150104b1ef02b228d94777541
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             aeson-1.3.1.1-5HUAx09wxP9QY0dgM2orK=a4f854631dd0eec57df5f1d1976bd18b
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.17.5.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-types
version: 1.17.5.1
id: pandoc-types-1.17.5.1-AzLabzrdxu2Gv0WdIubUhB
key: pandoc-types-1.17.5.1-AzLabzrdxu2Gv0WdIubUhB
license: BSD-3-Clause
copyright: (c) 2006-2017 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://johnmacfarlane.net/pandoc
synopsis: Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.
    .
    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.
    .
    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.
    .
    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.
    .
    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.
category: Text
abi: 6f2f533897060c7ab371d6545815e2f4
exposed: True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk
hidden-modules: Paths_pandoc_types
import-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-types-1.17.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-types-1.17.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pandoc-types-1.17.5.1
hs-libraries: HSpandoc-types-1.17.5.1-AzLabzrdxu2Gv0WdIubUhB
depends:
    base-4.11.1.0 containers-0.5.11.0 syb-0.7-2jW43lwzJV5e7EQvU8PxV
    ghc-prim-0.5.2.0 bytestring-0.10.8.2
    aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq transformers-0.5.5.0
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=5f5748e150104b1ef02b228d94777541
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq=0bddb8c122a0181e324f08c1b045cf5c
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock
haddock-html: /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
